@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::RJBS 5.027;
+package Dist::Zilla::PluginBundle::RJBS 5.028;
 # ABSTRACT: BeLike::RJBS when you build your dists
 
 use Moose;
@@ -64,7 +64,7 @@ use Dist::Zilla::PluginBundle::Basic;
 use Dist::Zilla::PluginBundle::Filter;
 use Dist::Zilla::PluginBundle::Git;
 
-package Dist::Zilla::Plugin::RJBSMisc 5.027 {
+package Dist::Zilla::Plugin::RJBSMisc 5.028 {
   use Moose;
   with 'Dist::Zilla::Role::BeforeBuild',
        'Dist::Zilla::Role::AfterBuild',
@@ -230,15 +230,12 @@ sub configure ($self) {
     } ],
   );
 
-  my $use_1P = length $ENV{DZIL_PAUSE_1P_ITEM_ID};
-
   $self->add_bundle('@Filter', {
     '-bundle' => '@Basic',
     '-remove' => [
       'GatherDir',
       'ExtraTests',
       'MakeMaker',
-      ($use_1P ? 'UploadToCPAN' : ()),
     ],
   });
 
@@ -249,12 +246,6 @@ sub configure ($self) {
     }
   ]);
 
-  if ($use_1P) {
-    $self->add_plugins([
-      'UploadToCPAN::OnePassword' => {},
-    ]);
-  }
-
   $self->add_plugins('AutoPrereqs');
 
   unless ($self->manual_version) {
@@ -372,7 +363,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 5.027
+version 5.028
 
 =head1 DESCRIPTION
 
